.. pydash documentation master file

.. include:: ../README.rst

.. include:: quickstart.rst


Guide
=====

.. toctree::
    :maxdepth: 2

    install
    quickstart
    differences
    callbacks
    deeppath
    chaining
    templating
    upgrading


API Reference
=============

Includes links to source code.

.. toctree::
    :maxdepth: 2

    api


Project Info
============

.. toctree::
    :maxdepth: 1

    license
    versioning
    changelog
    authors
    contributing
    kudos


Indices and Tables
==================

- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`

